searchNodes=[{"doc":"This module facilitates spawning nodes within tests. For using ExUnited, the two essential functions are: ExUnited.spawn/2 - Spawns (Mix.Config configured, additional code loaded, supervising) nodes ExUnited.teardown/0 - Kills the spawned nodes and it also cleans up their generated files The most simplest setup Nodes can be specified as a list of atoms, just like in the following example. Their node names will be :&quot;bruce@127.0.0.1&quot; and :&quot;clark@127.0.0.1&quot; respectively). Please do not forget to invoke ExUnited.teardown/0 at the on_exit hook. setup do {:ok, spawned} = ExUnited.spawn([:bruce, :clark]) on_exit(fn -&gt; ExUnited.teardown() end) spawned end &quot;Partially versus Fully connected&quot; and/or &quot;Verbose&quot; spawned nodes As a second argument, you can pass a list of atoms for the options: :connect - if true a &quot;fully connected&quot; node will be spawned (see the erl -connect_all flag for more information). Defaults to false :verbose - if true the STDOUT of the spawned node will be printed. Defaults to false See ExUnited.spawn/2 for more information. setup do {:ok, spawned} = ExUnited.spawn([:roy], [:connect, :verbose]) on_exit(fn -&gt; ExUnited.teardown() end) spawned end Which results in the following when running tests: PME-Legend ~/S/ex_united:master&gt; mix test test/ex_united/supervised_test.exs:140 Excluding tags: [:test] Including tags: [line: &quot;140&quot;] iex(roy@127.0.0.1)&gt; Compiling 1 file (.ex) iex(roy@127.0.0.1)&gt; Generated void app iex(roy@127.0.0.1)&gt; Interactive Elixir (1.10.1) - press Ctrl+C to exit (type h() ENTER for help) iex(roy@127.0.0.1)1&gt; . Finished in 0.9 seconds 2 tests, 0 failures, 1 excluded Exclude certain dependencies within spawned nodes You can exclude certain (Mix) dependencies from your spawned nodes by for instance adding exclude: [:inch_ex] to the options. This can significantly improve the speed of your tests. setup do {:ok, spawned} = ExUnited.spawn([:bruce, :clark], [:verbose, exclude: [:inch_ex]]) on_exit(fn -&gt; ExUnited.teardown() end) spawned end The following dependencies are excluded by default: :credo :dialyxir :ex_doc :ex_united :excoveralls Configuring the spawned nodes Aside from the list of atoms, you can also specify nodes as a keyword list in case you want to configure them. The following options are available: :code_paths - a list of directories that will be included :exclude - a list of dependencies that will be excluded :supervise - the child spec(s) used for supervisioning Including additional code It would be a best practice to create a directory called test/nodes in which you put a directory containing code for a specific spawned node. Please note that the file called config.exs is supported for Mix.Config: setup do {:ok, spawned} = ExUnited.spawn( eric: [ code_paths: [ &quot;test/nodes/cantona&quot; ] ] ) on_exit(fn -&gt; ExUnited.teardown() end) spawned end See test/ex_united/supervised_test.exs with its corresponding test/nodes/ronaldo as an example. Exclude certain dependencies for a specific spawned node Add the :exclude list as follows: setup do {:ok, spawned} = ExUnited.spawn( bruce: [ code_paths: [ &quot;test/nodes/bruce&quot; ], exclude: [ :my_unused_dependency ], supervise: [MyAwesomeGenServer] ], clark: [ code_paths: [ &quot;test/nodes/clark&quot; ], supervise: [MyOtherAwesomeGenServer] ] ) on_exit(fn -&gt; ExUnited.teardown() end) spawned end Add supervisioning Childspecs should be the same argument as if you are adding them to your classic &lt;app&gt;/application.ex file: setup do {:ok, spawned} = ExUnited.spawn( bruce: [ code_paths: [ &quot;test/nodes/bruce&quot; ], supervise: [MyAwesomeGenServer] ], clark: [ code_paths: [ &quot;test/nodes/clark&quot; ], supervise: [MyOtherAwesomeGenServer] ] ) on_exit(fn -&gt; ExUnited.teardown() end) spawned end Pay attention that functions within childspecs should be quoted. setup do {:ok, spawned} = ExUnited.spawn( [ roy: [ code_paths: [ &quot;test/nodes/keane&quot; ], supervise: [ { Roy, talk: quote do fn 1 -&gt; &quot;Hi, I am Roy Keane&quot; 2 -&gt; &quot;I am keen as mustard&quot; 3 -&gt; &quot;I like to be peachy keen&quot; end end } ] ] ], [:verbose] ) on_exit(fn -&gt; ExUnited.teardown() end) spawned end Easily assert and refute within the context of spawned nodes To seemlessly execute assertions and refutations within spawned nodes, you can setup your test module by either using ExUnited.Case instead of ExUnit.Case: defmodule MyNodesTest do use ExUnited.Case end Or by importing the ExUnited.Case module: defmodule MyNodesTest do use ExUnit.Case import ExUnited.Case end Writing assertions and refutations within the context of a certain spawned is pretty straight forward with the use of the ExUnited.Case.as_node/2 function as if you are writing your class assert and/or refute statements: defmodule MyNodesTest do use ExUnited.Case setup do {:ok, spawned} = ExUnited.spawn([:bruce, :clark]) on_exit(fn -&gt; ExUnited.teardown() end) spawned end test &quot;assertions and refutations within node contexts&quot;, spawned do bruce = get_in(spawned, [:bruce, :node]) as_node(bruce) do assert :&quot;bruce@127.0.0.1&quot; = Node.self() refute :&quot;clark@127.0.0.1&quot; == Node.self() end as_node(:clark) do assert :&quot;clark@127.0.0.1&quot; = Node.self() refute :&quot;bruce@127.0.0.1&quot; == Node.self() end end end See ExUnited.Case.as_node/2 for more information.","ref":"ExUnited.html","title":"ExUnited","type":"module"},{"doc":"","ref":"ExUnited.html#mix_exs/2","title":"ExUnited.mix_exs/2","type":"function"},{"doc":"Spawns nodes for testing purposes. Supervised applications are supported. Nodes can be either specified as a list of atoms (such as [:bruce, :clark] for instance; the node names will be :&quot;bruce@127.0.0.1&quot; and :&quot;clark@127.0.0.1&quot; respectively) or as a keyword list (in case of configuring the spawned node). The following options are available to configure nodes: :code_paths - a list of directories that will be included (please note that the file called config.exs is supported for Mix.Config) :exclude - a list of dependencies that will be excluded :include - a list of dependencies that will be included, in the format that is used in the mix file :supervise - the child spec(s) used for supervisioning Aside from options for configuring individual nodes, as a second argument, you can pass a list of atoms for the following: :connect - if true a &quot;fully connected&quot; node will be spawned (see the erl -connect_all flag for more information). Defaults to false :verbose - if true the STDOUT of the spawned node will be printed. Defaults to false And last but not least, you can exclude certain (Mix) dependencies from your spawned nodes by adding exclude: [:inch_ex] to the options. This can significantly improve the speed of your tests. The following dependencies are excluded by default: :credo :dialyxir :ex_doc :ex_united :excoveralls Examples The most simplest setup: setup do {:ok, spawned} = ExUnited.spawn([:bruce, :clark]) on_exit(fn -&gt; ExUnited.teardown() end) spawned end Spawn &quot;fully connected&quot; nodes and print all their STDOUT in the console: setup do {:ok, spawned} = ExUnited.spawn([:bruce, :clark], [:connect, :verbose]) on_exit(fn -&gt; ExUnited.teardown() end) spawned end Exclude certain dependencies for all nodes: setup do {:ok, spawned} = ExUnited.spawn([:bruce, :clark], [:verbose, exclude: [:inch_ex]]) on_exit(fn -&gt; ExUnited.teardown() end) spawned end A configured nodes setup: setup do {:ok, spawned} = ExUnited.spawn( bruce: [ code_paths: [ &quot;test/nodes/bruce&quot; ], supervise: [MyAwesomeGenServer] ], clark: [ code_paths: [ &quot;test/nodes/clark&quot; ], supervise: [MyOtherAwesomeGenServer] ] ) on_exit(fn -&gt; ExUnited.teardown() end) spawned end Exclude certain dependencies for a specific spawned node: setup do {:ok, spawned} = ExUnited.spawn( bruce: [ code_paths: [ &quot;test/nodes/bruce&quot; ], exclude: [ :my_unused_dependency ], supervise: [MyAwesomeGenServer] ], clark: [ code_paths: [ &quot;test/nodes/clark&quot; ], supervise: [MyOtherAwesomeGenServer] ] ) on_exit(fn -&gt; ExUnited.teardown() end) spawned end Include certain dependencies for a specific spawned node: setup do {:ok, spawned} = ExUnited.spawn( bruce: [ code_paths: [ &quot;test/nodes/bruce&quot; ], include: [ {:my_lib, &quot;&gt;= 0.0.0&quot;}, {:another_lib, &quot;~&gt; 1.0&quot;} ], supervise: [MyAwesomeGenServer] ], clark: [ code_paths: [ &quot;test/nodes/clark&quot; ], supervise: [MyOtherAwesomeGenServer] ] ) on_exit(fn -&gt; ExUnited.teardown() end) spawned end Also note that functions within childspecs should be quoted. setup do {:ok, spawned} = ExUnited.spawn( [ roy: [ code_paths: [ &quot;test/nodes/keane&quot; ], supervise: [ { Roy, talk: quote do fn 1 -&gt; &quot;Hi, I am Roy Keane&quot; 2 -&gt; &quot;I am keen as mustard&quot; 3 -&gt; &quot;I like to be peachy keen&quot; end end } ] ] ], [:verbose] ) on_exit(fn -&gt; ExUnited.teardown() end) spawned end","ref":"ExUnited.html#spawn/2","title":"ExUnited.spawn/2","type":"function"},{"doc":"Starts both the ExUnit and ExUnited.Spawn gen servers. This should replace the default ExUnit.start() invocation in the test helper file. # test/test_helper.exs ExUnited.start() As of version 0.1.2, you can also start ExUnit yourself explicitly and add ExUnited.start(false) instead: # test/test_helper.exs ExUnit.start() ExUnited.start(false)","ref":"ExUnited.html#start/1","title":"ExUnited.start/1","type":"function"},{"doc":"Should be invoked at the end of a test which spawned nodes. This kills the nodes and it also cleans up their generated files located in /tmp/[NODENAME]-{config,mix}.exs. Example defmodule MyNodesTest do use ExUnit.Case setup do {:ok, spawned} = ExUnited.spawn([:bruce, :clark]) on_exit(fn -&gt; ExUnited.teardown() end) spawned end test &quot;does awesome stuff with spawned nodes&quot;, spawned do # a lot of awesome assertions and refutations end end","ref":"ExUnited.html#teardown/0","title":"ExUnited.teardown/0","type":"function"},{"doc":"This module makes it possible to seemlessly execute assertions and refutations within spawned nodes. You can setup your test module by either using ExUnited.Case instead of ExUnit.Case: defmodule MyNodesTest do use ExUnited.Case end Or by importing the ExUnited.Case module: defmodule MyNodesTest do use ExUnit.Case import ExUnited.Case end Writing assertions and refutations within the context of a certain spawned is pretty straight forward with the use of the ExUnited.Case.as_node/2 function: Example defmodule MyNodesTest do use ExUnited.Case setup do {:ok, spawned} = ExUnited.spawn([:bruce, :clark]) on_exit(fn -&gt; ExUnited.teardown() end) spawned end test &quot;assertions and refutations within node contexts&quot;, spawned do bruce = get_in(spawned, [:bruce, :node]) as_node(bruce) do assert :&quot;bruce@127.0.0.1&quot; = Node.self() refute :&quot;clark@127.0.0.1&quot; == Node.self() end as_node(:clark) do assert :&quot;clark@127.0.0.1&quot; = Node.self() refute :&quot;bruce@127.0.0.1&quot; == Node.self() end end end See ExUnited.Case.as_node/2 for more information.","ref":"ExUnited.Case.html","title":"ExUnited.Case","type":"module"},{"doc":"Injects use ExUnit.Case and import ExUnited.Case, except: [send_error: 2] in the test module. Gets triggered after having put use ExUnited.Case in your test module.","ref":"ExUnited.Case.html#__using__/1","title":"ExUnited.Case.__using__/1","type":"macro"},{"doc":"A convenience macro function for writing assertions and refutations from within spawned nodes. It makes writing tests so much easier and more readable. The function accepts the following: node - the simple name (used during spawning) or the node name binding - a keyword list containing variables which will be available in the code block (optional) block - the code block containing assertions and/or refutations Example test &quot;assertions and refutations within the right context&quot;, spawned do clark = get_in(spawned, [:clark, :node]) bruce = get_in(spawned, [:bruce, :node]) assert :&quot;captain@127.0.0.1&quot; == Node.self() assert [:&quot;bruce@127.0.0.1&quot;, :&quot;clark@127.0.0.1&quot;] = Node.list() |&gt; Enum.sort() as_node(clark) do nodes = Node.list() refute :&quot;captain@127.0.0.1&quot; == Node.self() assert :&quot;clark@127.0.0.1&quot; = Node.self() assert [:&quot;captain@127.0.0.1&quot;] = Node.list() assert ^nodes = Node.list() end as_node(:bruce, spawned_node: bruce) do assert :&quot;bruce@127.0.0.1&quot; = Node.self() assert :&quot;bruce@127.0.0.1&quot; = spawned_node assert ^spawned_node = Node.self() assert ^spawned_node = :&quot;bruce@127.0.0.1&quot; assert [:&quot;captain@127.0.0.1&quot;] = Node.list() end end","ref":"ExUnited.Case.html#as_node/3","title":"ExUnited.Case.as_node/3","type":"macro"},{"doc":"This module is used by ExUnited to spawn nodes for testing purposes. ExUnited.Spawn uses the Elixir Port module for spawning and as it implements the GenServer behaviour it is able to store state containing information about the spawn nodes. You will probably not talk to this module directly. Though you can of course try out things in the console. Example iex(1)&gt; ExUnited.Spawn.start_link() {:ok, #PID&lt;0.198.0&gt;} iex(2)&gt; Node.start(:&quot;captain@127.0.0.1&quot;) {:ok, #PID&lt;0.200.0&gt;} iex(captain@127.0.0.1)3&gt; ExUnited.Spawn.summon(:&quot;bruce@127.0.0.1&quot;, env: [PORT: 5000], verbose: true) iex(bruce@127.0.0.1)&gt; Interactive Elixir (1.10.1) - press Ctrl+C to exit (type h() ENTER for help) iex(bruce@127.0.0.1)1&gt; {#Port&lt;0.8&gt;, &quot;iex --name bruce@127.0.0.1 --erl &#39;-connect_all false&#39; -S mix run -e &#39;Node.connect(:&quot;captain@127.0.0.1&quot;)&#39;&quot;, [{&#39;PORT&#39;, &#39;5000&#39;}]} iex(captain@127.0.0.1)4&gt; Node.list() [:&quot;bruce@127.0.0.1&quot;] iex(captain@127.0.0.1)5&gt; ExUnited.Spawn.legion() %ExUnited.Spawn.State{ color_index: 1, nodes: %{bruce: %{color: &quot;38&quot;, node: :&quot;bruce@127.0.0.1&quot;, port: #Port&lt;0.8&gt;}} } iex(captain@127.0.0.1)6&gt; ExUnited.Spawn.kill_all() :ok","ref":"ExUnited.Spawn.html","title":"ExUnited.Spawn","type":"module"},{"doc":"Returns a specification to start this module under a supervisor. See Supervisor.","ref":"ExUnited.Spawn.html#child_spec/1","title":"ExUnited.Spawn.child_spec/1","type":"function"},{"doc":"Kills and unregisters a spawned node identified by its node name or port.","ref":"ExUnited.Spawn.html#kill/1","title":"ExUnited.Spawn.kill/1","type":"function"},{"doc":"Kills and unregisters all spawned nodes. If either of the nodes failed to be killed the return value will be :noop and elsewise the return value is :ok.","ref":"ExUnited.Spawn.html#kill_all/0","title":"ExUnited.Spawn.kill_all/0","type":"function"},{"doc":"Returns a %ExUnited.Spawn.State{} containing all its spawned nodes. iex(captain@127.0.0.1)8&gt; ExUnited.Spawn.legion() %ExUnited.Spawn.State{ color_index: 4, nodes: %{ bruce: %{color: nil, node: :&quot;bruce@127.0.0.1&quot;, port: #Port&lt;0.8&gt;}, clark: %{color: &quot;214&quot;, node: :&quot;clark@127.0.0.1&quot;, port: #Port&lt;0.12&gt;}, peter: %{color: &quot;38&quot;, node: :&quot;peter@127.0.0.1&quot;, port: #Port&lt;0.10&gt;}, steven: %{color: &quot;112&quot;, node: :&quot;steven@127.0.0.1&quot;, port: #Port&lt;0.16&gt;}, tony: %{color: &quot;199&quot;, node: :&quot;tony@127.0.0.1&quot;, port: #Port&lt;0.14&gt;} } } See ExUnited.Spawn.State for more information.","ref":"ExUnited.Spawn.html#legion/0","title":"ExUnited.Spawn.legion/0","type":"function"},{"doc":"Starts the spawn server. The gen server spawnes nodes and stores their references in its state.","ref":"ExUnited.Spawn.html#start_link/0","title":"ExUnited.Spawn.start_link/0","type":"function"},{"doc":"Spawns a new node using the specified node name. These options are supported: :env - should be a keyword list containing the environment variables which will be used for the spawned node :connect - if true a &quot;fully connected&quot; node will be spawned (see the erl -connect_all flag for more information). Defaults to false :verbose - if true the STDOUT of the spawned node will be printed. Defaults to false It returns a tuple conforming the following structure: {node, port, command, env} where: node - the full nodename of the spawned node (the Node.self() value) port - the corresponding Port reference of the spawned node command - the command used for spawning the node env - the list containing environment variables used spawning the node Example {node, port, command, env} = ExUnited.Spawn.summon(:&quot;peter@127.0.0.1&quot;, [ MIX_EXS: &quot;/tmp/peter-mix.exs&quot;, verbose: true ]) If the name already seems to be registered then a :noop will be returned without spawning the node.","ref":"ExUnited.Spawn.html#summon/2","title":"ExUnited.Spawn.summon/2","type":"function"},{"doc":"A struct containing information about a spawned node for use in ExUnit tests: :node - the node name of the spawned node :port - the corresponding Port reference of the spawned node :command - the command used for spawning the node :env - the list containing environment variables used spawning the node See ExUnited.Spawn.summon/2 for more information.","ref":"ExUnited.Node.html","title":"ExUnited.Node","type":"module"},{"doc":"","ref":"ExUnited.Node.html#t:t/0","title":"ExUnited.Node.t/0","type":"type"},{"doc":"Represents the state of an ExUnited.Spawn instance. It stores: :color_index - a cycling index used for allocating the output color of the next node to be spawned with &#39;verbose mode&#39; enabled :nodes - a map containing information about its spawned nodes","ref":"ExUnited.Spawn.State.html","title":"ExUnited.Spawn.State","type":"module"},{"doc":"A struct that keeps information about a spawned node: :node - the node name of the spawned node :port - the Port reference after having spawned the node :color - the ANSI color code portion used when in &#39;verbose mode&#39;","ref":"ExUnited.Spawn.State.html#t:spawned_node/0","title":"ExUnited.Spawn.State.spawned_node/0","type":"type"},{"doc":"","ref":"ExUnited.Spawn.State.html#t:t/0","title":"ExUnited.Spawn.State.t/0","type":"type"},{"doc":"ExUnited Easily spawn Elixir nodes (supervising, Mix configured, easy asserted / refuted) within ExUnit tests","ref":"readme.html","title":"ExUnited","type":"extras"},{"doc":"ExUnited is a Hex package designed to easily facilitate spawning supervising local Elixir nodes within tests. Unfortunately, I was not able to properly setup a spawned node for supervisioning with the Erlang :slave.start_link/1 function. So I have written ExUnited to accomplish that, along with supporting Mix.Config configurations, additional loaded code, and a developer friendly way of writing assertions and refutations in the context of a spawned node which really improved the readability of the tests and more.","ref":"readme.html#introduction","title":"ExUnited - Introduction","type":"extras"},{"doc":"Spawn nodes for testing purposes Spin up &quot;partially connected&quot; vs &quot;fully connected&quot; nodes Run in &quot;verbose&quot; mode which prints a colorized STDOUT of the nodes Specify extra &quot;code paths&quot; which will be included (config.exs included) Support child supervisioning within a spawned node Exclude certain dependencies for spawned nodes Easily(!) assert and refute within the context of spawned nodes Enjoy the package! I would love to receive a shoutout and/or your feedback ;)","ref":"readme.html#features","title":"ExUnited - Features","type":"extras"},{"doc":"To install ExUnited, please add ex_united to your list of dependencies in mix.exs: def deps do [ {:ex_united, &quot;~&gt; 0.1.4&quot;, only: :test} ] end Replace the default ExUnit.start() invocation in the test helper file with ExUnited.start(): # test/test_helper.exs ExUnited.start() Explicitly start ExUnit yourself As of version 0.1.2, you can also start ExUnit yourself explicitly and add ExUnited.start(false) instead: # test/test_helper.exs ExUnit.start() ExUnited.start(false) ATTENTION: When also using meck-based packages The following errors can occur when also using packages like mock or MecksUnit (which both use the Erlang library meck to mock functions) and spawning the nodes with the default environment test: (UndefinedFunctionError) function Some.Module.some_function/1 is undefined (ErlangError) Erlang error: {{:undefined_module, &lt; Some.Module &gt;} To tackle this, you should configure any other (Mix) environment to spawn the nodes with. Configure it like so: # config/test.exs import Config config :ex_united, mix_env: :dev You might also want to consider using a bogus environment (e.g. :void) to skip the non-relevant :dev dependencies, like credo or dialyxir probably. That will save some compile time. And last but not least, please note that using a different environment within CI builds will require compiling the project in that particular environment on beforehand of the tests. Otherwise spawning the nodes will take too much time and that will cause timeout errors during the tests. # .gitlab-ci.yml before_script: ... - MIX_ENV=void mix deps.get - MIX_ENV=void mix run -e &#39;IO.puts(&quot;Done.&quot;)&#39; - epmd -daemon script: - mix test","ref":"readme.html#installation","title":"ExUnited - Installation","type":"extras"},{"doc":"For using ExUnited, the two essential functions are: ExUnited.spawn/2 - Spawns (Mix.Config configured, additional code loaded, supervising) nodes ExUnited.teardown/0 - Kills the spawned nodes and it also cleans up their generated files The most simplest setup Nodes can be specified as a list of atoms, just like in the following example. Their node names will be :&quot;bruce@127.0.0.1&quot; and :&quot;clark@127.0.0.1&quot; respectively). Please do not forget to invoke ExUnited.teardown/0 at the on_exit hook. setup do {:ok, spawned} = ExUnited.spawn([:bruce, :clark]) on_exit(fn -&gt; ExUnited.teardown() end) spawned end &quot;Partially versus Fully connected&quot; and/or &quot;Verbose&quot; spawned nodes As a second argument, you can pass a list of atoms for the options: :connect - if true a &quot;fully connected&quot; node will be spawned (see the erl -connect_all flag for more information). Defaults to false :verbose - if true the STDOUT of the spawned node will be printed. Defaults to false See ExUnited.spawn/2 for more information. setup do {:ok, spawned} = ExUnited.spawn([:roy], [:connect, :verbose]) on_exit(fn -&gt; ExUnited.teardown() end) spawned end Which results in the following when running tests: PME-Legend ~/S/ex_united:master&gt; mix test test/ex_united/supervised_test.exs:140 Excluding tags: [:test] Including tags: [line: &quot;140&quot;] iex(roy@127.0.0.1)&gt; Compiling 1 file (.ex) iex(roy@127.0.0.1)&gt; Generated void app iex(roy@127.0.0.1)&gt; Interactive Elixir (1.10.1) - press Ctrl+C to exit (type h() ENTER for help) iex(roy@127.0.0.1)1&gt; . Finished in 0.9 seconds 2 tests, 0 failures, 1 excluded Exclude certain dependencies for all spawned nodes You can exclude certain (Mix) dependencies for ALL spawned nodes by for instance adding exclude: [:inch_ex] to the options. This can significantly improve the speed of your tests. setup do {:ok, spawned} = ExUnited.spawn([:bruce, :clark], [:verbose, exclude: [:inch_ex]]) on_exit(fn -&gt; ExUnited.teardown() end) spawned end The following dependencies are excluded by default: :credo :dialyxir :ex_doc :ex_united :excoveralls Configuring the spawned nodes Aside from the list of atoms, you can also specify nodes as a keyword list in case you want to configure them. The following options are available: :code_paths - a list of directories that will be included :exclude - a list of dependencies that will be excluded :supervise - the child spec(s) used for supervisioning Including additional code It would be a best practice to create a directory called test/nodes in which you put a directory containing code for a specific spawned node. Please note that the file called config.exs is supported for Mix.Config: setup do {:ok, spawned} = ExUnited.spawn( eric: [ code_paths: [ &quot;test/nodes/cantona&quot; ] ] ) on_exit(fn -&gt; ExUnited.teardown() end) spawned end See test/ex_united/supervised_test.exs with its corresponding test/nodes/ronaldo as an example. Exclude certain dependencies for a specific spawned node Add the :exclude list as follows: setup do {:ok, spawned} = ExUnited.spawn( bruce: [ code_paths: [ &quot;test/nodes/bruce&quot; ], exclude: [ :my_unused_dependency, :my_current_project ], supervise: [MyAwesomeGenServer] ], clark: [ code_paths: [ &quot;test/nodes/clark&quot; ], supervise: [MyOtherAwesomeGenServer] ] ) on_exit(fn -&gt; ExUnited.teardown() end) spawned end Add supervisioning Childspecs should be the same argument as if you are adding them to your classic &lt;app&gt;/application.ex file: setup do {:ok, spawned} = ExUnited.spawn( bruce: [ code_paths: [ &quot;test/nodes/bruce&quot; ], supervise: [MyAwesomeGenServer] ], clark: [ code_paths: [ &quot;test/nodes/clark&quot; ], supervise: [MyOtherAwesomeGenServer] ] ) on_exit(fn -&gt; ExUnited.teardown() end) spawned end Pay attention that functions within childspecs should be quoted. setup do {:ok, spawned} = ExUnited.spawn( [ roy: [ code_paths: [ &quot;test/nodes/keane&quot; ], supervise: [ { Roy, talk: quote do fn 1 -&gt; &quot;Hi, I am Roy Keane&quot; 2 -&gt; &quot;I am keen as mustard&quot; 3 -&gt; &quot;I like to be peachy keen&quot; end end } ] ] ], [:verbose] ) on_exit(fn -&gt; ExUnited.teardown() end) spawned end Easily assert and refute within the context of spawned nodes To seemlessly execute assertions and refutations within spawned nodes, you can setup your test module by either using ExUnited.Case instead of ExUnit.Case: defmodule MyNodesTest do use ExUnited.Case end Or by importing the ExUnited.Case module: defmodule MyNodesTest do use ExUnit.Case import ExUnited.Case end Writing assertions and refutations within the context of a certain spawned is pretty straight forward with the use of the ExUnited.Case.as_node/2 function as if you are writing your class assert and/or refute statements: defmodule MyNodesTest do use ExUnited.Case setup do {:ok, spawned} = ExUnited.spawn([:bruce, :clark]) on_exit(fn -&gt; ExUnited.teardown() end) spawned end test &quot;assertions and refutations within node contexts&quot;, spawned do bruce = get_in(spawned, [:bruce, :node]) as_node(bruce) do assert :&quot;bruce@127.0.0.1&quot; = Node.self() refute :&quot;clark@127.0.0.1&quot; == Node.self() end as_node(:clark) do assert :&quot;clark@127.0.0.1&quot; = Node.self() refute :&quot;bruce@127.0.0.1&quot; == Node.self() end end end See ExUnited.Case.as_node/2 for more information.","ref":"readme.html#usage","title":"ExUnited - Usage","type":"extras"},{"doc":"For support, remarks and requests, please mail me at pm_engel@icloud.com.","ref":"readme.html#contact-me","title":"ExUnited - Contact me","type":"extras"},{"doc":"Copyright (c) 2020 Paul Engel, released under the MIT License http://github.com/archan937 – http://twitter.com/archan937 – pm_engel@icloud.com Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files (the &quot;Software&quot;), to deal in the Software without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions: The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software. THE SOFTWARE IS PROVIDED &quot;AS IS&quot;, WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.","ref":"readme.html#license","title":"ExUnited - License","type":"extras"},{"doc":"Changelog","ref":"changelog.html","title":"Changelog","type":"extras"},{"doc":"Added include spawn option (credits to @thomas9911)","ref":"changelog.html#v0-1-4","title":"Changelog - v0.1.4","type":"extras"},{"doc":"Add necessary configs to run on umbrella projects (credits to @PinheiroRodrigo)","ref":"changelog.html#v0-1-3","title":"Changelog - v0.1.3","type":"extras"},{"doc":"Add ability to use a different MIX_ENV when spawning nodes (solves meck related testing problems) Add boolean flag to not start ExUnit","ref":"changelog.html#v0-1-2","title":"Changelog - v0.1.2","type":"extras"},{"doc":"Add :exclude option for individual spawned nodes Exclude current project as dependency (instead, add &quot;lib&quot; to code paths) Do not generate config files Fix redundant prompt when in verbose mode","ref":"changelog.html#v0-1-1","title":"Changelog - v0.1.1","type":"extras"},{"doc":"Initial commit Spawn nodes for testing purposes Spin up &quot;partially connected&quot; vs &quot;fully connected&quot; nodes Run in &quot;verbose&quot; mode which prints a colorized STDOUT of the nodes Specify extra &quot;code paths&quot; which will be included (config.exs included) Support child supervisioning within a spawned node Exclude certain dependencies for spawned nodes Easily(!) assert and refute within the context of spawned nodes","ref":"changelog.html#v0-1-0","title":"Changelog - v0.1.0","type":"extras"}]